@@ -25,6 +25,7 @@
 #include <locale.h>
 #include <gio/gio.h>
 #include <libsoup/soup.h>
+#include <langinfo.h>
 #include <geocode-glib/geocode-glib-private.h>
 
 /**
@@ -36,29 +37,6 @@
  * <ulink url="http://wiki.openstreetmap.org/wiki/Nominatim">OSM Nominatim APIs</ulink>
  **/
 
-SoupSession *
-_geocode_glib_build_soup_session (void)
-{
-	GApplication *application;
-	SoupSession *session;
-	char *user_agent;
-
-	application = g_application_get_default ();
-	if (application) {
-		const char *id = g_application_get_application_id (application);
-		user_agent = g_strdup_printf ("geocode-glib/%s (%s)",
-					      PACKAGE_VERSION, id);
-	} else {
-		user_agent = g_strdup_printf ("geocode-glib/%s",
-					      PACKAGE_VERSION);
-	}
-
-	session = soup_session_new_with_options (SOUP_SESSION_USER_AGENT,
-						 user_agent, NULL);
-	g_free (user_agent);
-	return session;
-}
-
 char *
 _geocode_glib_cache_path_for_query (SoupMessage *query)
 {
@@ -211,3 +189,46 @@ _geocode_object_get_lang (void)
 {
 	return geocode_object_get_lang_for_locale (setlocale (LC_MESSAGES, NULL));
 }
+
+#ifdef __GLIBC__
+static gpointer
+is_number_after_street (gpointer data)
+{
+	gboolean retval;
+	gchar *addr_format;
+	gchar *s;
+	gchar *h;
+
+	addr_format = nl_langinfo (_NL_ADDRESS_POSTAL_FMT);
+	if (addr_format == NULL) {
+		retval = FALSE;
+		goto out;
+	}
+
+	/* %s denotes street or block and %h denotes house number.
+	 * See: http://lh.2xlibre.net/values/postal_fmt */
+	s = g_strstr_len (addr_format, -1, "%s");
+	h = g_strstr_len (addr_format, -1, "%h");
+
+	if (s != NULL && h != NULL)
+		retval = (h > s);
+	else
+		retval = FALSE;
+
+ out:
+	return GINT_TO_POINTER (retval);
+}
+#endif
+
+gboolean
+_geocode_object_is_number_after_street (void)
+{
+#ifndef __GLIBC__
+	return FALSE;
+#else
+	static GOnce once = G_ONCE_INIT;
+
+	g_once (&once, is_number_after_street, NULL);
+	return GPOINTER_TO_INT (once.retval);
+#endif
+}
