@@ -318,7 +318,7 @@ test_search_lat_long (void)
 	GeocodeLocation *loc;
 	GeocodeBoundingBox *bbox;
 
-	object = geocode_forward_new_for_string ("Santa María del Río");
+	object = geocode_forward_new_for_string ("Santa María del Río, San Luis Potosi");
 	res = geocode_forward_search (object, &error);
 	if (res == NULL) {
 		g_warning ("Failed at geocoding: %s", error->message);
@@ -338,11 +338,8 @@ test_search_lat_long (void)
 	g_assert_cmpfloat (geocode_location_get_latitude (loc) - 21.801729, <, 0.000001);
 	g_assert_cmpfloat (geocode_location_get_longitude (loc) - -100.737418, <, 0.000001);
 	g_assert (bbox_includes_location (bbox, geocode_place_get_location (place)));
-	g_assert_cmpstr (geocode_place_get_name (place), ==, "Santa Maria Del Rio, Mexico");
-	g_assert_cmpstr (geocode_place_get_town (place), ==, "Santa Maria Del Rio");
-	g_assert_cmpstr (geocode_place_get_state (place), ==, "San Luis Potosi");
-	g_assert_cmpstr (geocode_place_get_country (place), ==, "Mexico");
-	g_assert_cmpstr (geocode_location_get_description (loc), ==, "Santa Maria Del Rio, Mexico");
+	g_assert_cmpstr (geocode_place_get_name (place), ==, "Santa Mar\303\255a del Rio, Santa Mar\303\255a del Rio");
+	g_assert_cmpstr (geocode_location_get_description (loc), ==, "Santa Mar\303\255a del Rio, Santa Mar\303\255a del Rio");
 
 	g_list_free_full (res, (GDestroyNotify) g_object_unref);
 }
@@ -361,7 +358,7 @@ test_osm_type (void)
 	} types[] = {
 		{ "Drottning Christinas väg", GEOCODE_PLACE_OSM_TYPE_WAY },
 		{ "North dakota", GEOCODE_PLACE_OSM_TYPE_RELATION },
-		{ "Grand canyon", GEOCODE_PLACE_OSM_TYPE_NODE }
+		{ "Grand canyon, USA", GEOCODE_PLACE_OSM_TYPE_NODE }
 	};
 	for (i = 0; i < G_N_ELEMENTS (types); i++) {
 		object = geocode_forward_new_for_string (types[i].search_string);
@@ -374,7 +371,8 @@ test_osm_type (void)
 		g_object_unref (object);
 
 		place = res->data;
-		g_assert (geocode_place_get_osm_type (place) == types[i].osm_type);
+		g_test_message ("Location: %s", types[i].search_string);
+		g_assert_cmpint (geocode_place_get_osm_type (place), ==, types[i].osm_type);
 		g_list_free_full (res, (GDestroyNotify) g_object_unref);
 	}
 }
